/**
 * Copyright (C) 2008-2012 AgroSense Foundation.
 *
 * AgroSense is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * There are special exceptions to the terms and conditions of the GPLv3 as it is applied to
 * this software, see the FLOSS License Exception
 * <http://www.agrosense.eu/foss-exception.html>.
 *
 * AgroSense is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with AgroSense.  If not, see <http://www.gnu.org/licenses/>.
 */
package nl.cloudfarming.client.imp;

import java.io.IOException;
import java.util.Iterator;
import java.util.logging.Level;
import java.util.logging.Logger;
import org.netbeans.api.project.Project;
import org.openide.filesystems.FileObject;
import org.openide.filesystems.FileUtil;
import org.openide.loaders.DataObject;

/**
 *
 * @author johan
 */
public abstract class AbstractImportProcessor implements ImportProcessor {
    private static final Logger LOGGER = Logger.getLogger("nl.cloudfarming.client.imp.AbstractImportProcessor");        
    

    protected void copySourceFiles(DataObject dataObject, FileObject targetFolder) {
        Iterator<FileObject> files = dataObject.files().iterator();
        while (files.hasNext()) {
            FileObject current = files.next();
            try {
                String newFileName = FileUtil.findFreeFileName(targetFolder, current.getName(), current.getExt());
                FileUtil.copyFile(current, targetFolder, newFileName);
            } catch (IOException ex) {
                LOGGER.log(Level.SEVERE, "Could not copy file {0} with the exception {1}", new Object[]{current.getName(), ex});
            }
        }
    }
    
    protected final FileObject getImportRootFolder(Project project) {
        return getSubFolder(project.getProjectDirectory(), IMPORT_FOLDER);
    }

    protected FileObject getSubFolder(FileObject parentFolder, String name) {
        return getSubFolder(parentFolder, name, true);
    }
    
    protected FileObject getSubFolder(FileObject parentFolder, String name, boolean create) {
        FileObject result = parentFolder.getFileObject(name);
        if (result == null && create) {
            try {
                result = parentFolder.createFolder(name);
            } catch (IOException ioe) {
                LOGGER.log(Level.SEVERE, "Could not find or create folder {0} with the exception {1}", new Object[]{name, ioe});
            }
        }
        return result;    
    }
    
}
